from abc import ABC, abstractmethod
from enum import Enum
from typing import TypeVar, Generic

T = TypeVar("T", bound=Enum)


class Toggleable(Generic[T], ABC):

    @classmethod
    @abstractmethod
    def type(cls) -> T | list[T]:
        pass



from abc import ABC
from typing import TypeVar

from wwtp.api.settings import IScenarioSettings

SS = TypeVar('SS', bound=IScenarioSettings)


class SplitUnit(ABC):
    def __init__(
            self,
            scenario_settings: SS,
    ): self.scenario_settings = scenario_settings



def version(*, major: int, minor: int, patch: int):
    def decorate(ref):
        setattr(ref, 'major', major)
        setattr(ref, 'minor', minor)
        setattr(ref, 'patch', patch)
        return ref
    return decorate



from abc import ABC
from dataclasses import dataclass
from typing import TypeVar, Union


@dataclass
class FlowType(ABC):
    def __init__(self, **kwargs):
        for name, value in kwargs.items():
            setattr(self, name, value)


UseInputAsOutput = TypeVar("UseInputAsOutput", bound=Union[FlowType])
